# Generated by ariadne-codegen on 2024-03-30 09:48
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimSubscriptionFragment


class CreateSubscription(BaseModel):
    create_subscription: "CreateSubscriptionCreateSubscription" = Field(
        alias="createSubscription"
    )


class CreateSubscriptionCreateSubscription(SlimSubscriptionFragment):
    pass


CreateSubscription.update_forward_refs()
CreateSubscriptionCreateSubscription.update_forward_refs()
