# Generated by ariadne-codegen on 2024-03-30 09:48
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import ProvisionCustomerFragment


class ProvisionCustomer(BaseModel):
    provision_customer: "ProvisionCustomerProvisionCustomer" = Field(
        alias="provisionCustomer"
    )


class ProvisionCustomerProvisionCustomer(ProvisionCustomerFragment):
    pass


ProvisionCustomer.update_forward_refs()
ProvisionCustomerProvisionCustomer.update_forward_refs()
