# Generated by ariadne-codegen on 2024-03-30 09:48
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import UsageHistoryFragment


class GetUsageHistory(BaseModel):
    usage_history: "GetUsageHistoryUsageHistory" = Field(alias="usageHistory")


class GetUsageHistoryUsageHistory(UsageHistoryFragment):
    pass


GetUsageHistory.update_forward_refs()
GetUsageHistoryUsageHistory.update_forward_refs()
